{% extends "base.html" %}

{% block head %}
  <meta http-equiv="refresh" content="1;url={{ open_url }}" />
{% endblock %}

{% block body %}
  {% call spinner() %}
    <h5>
      This page should redirect you to voila. If it doesn't, <a href="{{ open_url }}">click here to go to voila</a>.
    </h5>
  {% endcall %}
{% endblock %}
